# Python ntubSystem Packages
---
**NTUB的Python版選課系統BETA版正式上線啦！**
![Python 3.6](https://img.shields.io/static/v1?label=Python&message=3.6&color=blue)
## 概述
---
我寫了這個NTUB選課系統，因為學校新學期開學時，選課常常當機讓我感
到非常不舒服，所以去Dcard上找到版上有些人寫出了他們學校的選課系統
不但可以解決選課當機的問題，還能選到課。
## 免責聲明
---
這個程式雖然能快速選到課，但並不保證能選到自己要的課程。比如學校的
通識課，或者你用程式時己經滿的課程。
[Dcard上對於搶課的看法](https://www.dcard.tw/f/ncue/p/224797792)
## 安裝方式
---
1. [點我進Anaconda](https://www.anaconda.com/products/individual)
1. 把Anaconda下載完後安裝
1. 接著在[開始功能表](https://zh.wikipedia.org/wiki/%E9%96%8B%E5%A7%8B%E5%8A%9F%E8%83%BD%E8%A1%A8)找Anaconda3
1. 點開找Anaconda Powershell
1. 打開它輸入如下指令
```
pip install ntubSystem
python -m ntubSystem
```
到了這步就完成了。
